
# 2.1.1 (2025 - 10 - 19)

Dropped support for `python3.9`.

### Features

* **datasets:** Added bars and stripes dataset.
* **visualization:** Added `show_images_dataset` for visualisation of image datasets.


# 2.0.1 (2025 - 05 - 12)

### Features

* **input validation:** Add basic input validation for int/prob
* **test_size:** Add test size to functions
* **spiky_time_series:** added spiky_time_series dataset

### BREAKING CHANGES

* **datasets:** The `get_linearly_separables_dataset` method has been
removed. It was a type and a deprication warning has been raised in
previous iterations of the dataset package.


# 1.2.0 (2023 - 02 - 09)

* **Initial public release:** Sklearn dataset wrappers.